-- Agrega columna para la identificacion de los grupos de productos de la sucursal
ALTER TABLE cat_sucursales
   ADD COLUMN `grupos` TEXT NULL AFTER `cantidad_mayoreo`;

UPDATE cat_sucursales
SET grupos = '';

-- Agrega columna para identificacion de grupo del producto
ALTER TABLE cat_productos_servicios
   ADD COLUMN `id_grupo` INT NULL AFTER `fecha_modificacion`;

UPDATE cat_productos_servicios
SET id_grupo = 0;

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateSucursal`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateSucursal`(
    in_id_sucursal INT,
    in_nombre VARCHAR(75),
    in_calle VARCHAR(100),
    in_colonia VARCHAR(50),
    in_codigo_postal VARCHAR(10),
    in_id_estado INT,
    in_id_municipio INT,
    in_telefonos VARCHAR(50),
    in_tasa DECIMAL(7,2),
    in_activo BOOL,
    in_matriz BOOL,
    in_num_ext VARCHAR(5),
    in_num_int VARCHAR(20),
    in_mensaje_ticket TEXT,
    in_cantidad_mayoreo INT,
	in_grupos TEXT
)
    COMMENT 'Inserta o actualiza una Sucursal'
BEGIN
    INSERT INTO cat_sucursales
    SET id_sucursal = in_id_sucursal,
        nombre = in_nombre,
        calle = in_calle,
        colonia = in_colonia,
        codigo_postal = in_codigo_postal,
        id_estado = in_id_estado,
        id_municipio = in_id_municipio,
        telefonos = in_telefonos,
        tasa = in_tasa,
        activo = in_activo,
        matriz = in_matriz,
        num_ext = in_num_ext,
        num_int = in_num_int,
        mensaje_ticket = in_mensaje_ticket,
        cantidad_mayoreo = in_cantidad_mayoreo,
        grupos = in_grupos
    ON DUPLICATE KEY
    UPDATE nombre = in_nombre,
        calle = in_calle,
        colonia = in_colonia,
        codigo_postal = in_codigo_postal,
        id_estado = in_id_estado,
        id_municipio = in_id_municipio,
        telefonos = in_telefonos,
        tasa = in_tasa,
        activo = in_activo,
        matriz = in_matriz,
        num_ext = in_num_ext,
        num_int = in_num_int,
        mensaje_ticket = in_mensaje_ticket,
        cantidad_mayoreo = in_cantidad_mayoreo,
        grupos = in_grupos;
END$$

DELIMITER ;

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateProducto`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateProducto`(
    in_id_producto INT,
    in_clave VARCHAR(20),
    in_codigo VARCHAR(20),
    in_codigo_proveedor VARCHAR(80),
    in_nombre VARCHAR(100),
    in_modelo VARCHAR(100),
    in_descripcion TEXT,
    in_precio_venta DECIMAL(15,2),
    in_tasa_iva DECIMAL(7,2),
    in_peso VARCHAR(15),
    in_longitud VARCHAR(15),
    in_superficie VARCHAR(15),
    in_volumen VARCHAR(15),
    in_id_unidad_medida INT,
    in_tipo_producto INT,
    in_iva_incluido INT,
    in_imagen TEXT,
    in_id_grupo INT
)
    COMMENT 'Inserta o actualiza un Producto'
BEGIN
    INSERT INTO cat_productos_servicios
    SET id_producto = in_id_producto,
        clave = in_clave,
        codigo = in_codigo,
        codigo_proveedor = in_codigo_proveedor,
        nombre = in_nombre,
        modelo = in_modelo,
        descripcion = in_descripcion,
        precio_venta = in_precio_venta,
        tasa_iva = in_tasa_iva,
        peso = in_peso,
        longitud = in_longitud,
        superficie = in_superficie,
        volumen = in_volumen,
        id_unidad_medida = in_id_unidad_medida,
        tipo_producto = in_tipo_producto,
        iva_incluido = in_iva_incluido,
        imagen = in_imagen,
        id_grupo = in_id_grupo
    ON DUPLICATE KEY
    UPDATE clave = in_clave,
        codigo = in_codigo,
        codigo_proveedor = in_codigo_proveedor,
        nombre = in_nombre,
        modelo = in_modelo,
        descripcion = in_descripcion,
        precio_venta = in_precio_venta,
        tasa_iva = in_tasa_iva,
        peso = in_peso,
        longitud = in_longitud,
        superficie = in_superficie,
        volumen = in_volumen,
        id_unidad_medida = in_id_unidad_medida,
        tipo_producto = in_tipo_producto,
        iva_incluido = in_iva_incluido,
        imagen = in_imagen,
        id_grupo = in_id_grupo;
END$$

DELIMITER ;

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_depurarProductos`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_depurarProductos`()
SQL SECURITY INVOKER
COMMENT 'Depura productos que no estan en los grupos de la sucursal'
BEGIN
    SET @vGrupos = "";
    
    SELECT s.grupos INTO @vGrupos
    FROM cat_configuracion AS c
    JOIN cat_sucursales AS s
        ON s.id_sucursal = c.id_sucursal;
    
    SET @_stmt = "
        DELETE FROM cat_productos_servicios
        WHERE id_grupo NOT IN (<<GRUPOS>>);
    ";
    
    SET @_stmt = REPLACE(@_stmt, '<<GRUPOS>>', @vGrupos);
    
    -- Ejecuta búsqueda
    PREPARE STMT FROM @_stmt;
    EXECUTE STMT;
    
    SELECT ROW_COUNT() AS eliminados;
END$$

DELIMITER ;

-- Actualiza el nombre del ultimo script actualizado
UPDATE cat_configuracion
SET last_script = 'SQL_20190130';
